Class: Animations | Chart.js
Description: Open source HTML5 Charts for your website

# # Class: Animations

## # Constructors

### # constructor

• new Animations(`chart`, `animations`)

#### # Parameters

Name | Type
--- | ---
`chart` | `Chart`<keyof `ChartTypeRegistry`, (`number` | `ScatterDataPoint` | `BubbleDataPoint`)[], `unknown`>
`animations` | `AnyObject`

#### # Defined in

animation.d.ts:30
(opens new window)

## # Methods

### # configure

▸ configure(`animations`): `void`

#### # Parameters

Name | Type
--- | ---
`animations` | `AnyObject`

#### # Returns

`void`

#### # Defined in

animation.d.ts:31
(opens new window)

### # update

▸ update(`target`, `values`): `boolean`

#### # Parameters

Name | Type
--- | ---
`target` | `AnyObject`
`values` | `AnyObject`

#### # Returns

`boolean`

#### # Defined in

animation.d.ts:32
(opens new window)